Data simulation plugin for Quantiphyse
======================================

This plugin provides data simulation tools.

Quantiphyse and quantiphyse-fabber must be installed. To
install the plugin from PyPi use:

    pip install quantiphyse-datasim

The plugin will then be available from within Quantiphyse

